Components
==========

Twitter Rehydration
===================

GeoLocation
===========

We currently embed one component for geolocation that is based on the online endpoint provided
by geonames. This component is going to try to disambiguate the location field in user profiles

Demographics Attributes
=======================

M3 Inference Classifier

We are currently implementing another classifier based on the FairFace.

General Classification
======================

We support any HuggingFace classifier by default

Topic Modeling
==============

We include CTM by default but we are working on adding additional text clustering methods for your data.

CTM can be used on multilingual data.

